@@ -114,7 +114,9 @@ class TokenCreateSerializer(serializers.Serializer):
     def validate(self, attrs):
         password = attrs.get("password")
         params = {settings.LOGIN_FIELD: attrs.get(settings.LOGIN_FIELD)}
-        self.user = authenticate(request=self.context.get("request"), **params, password=password)
+        self.user = authenticate(
+            request=self.context.get("request"), **params, password=password
+        )
         if not self.user:
             self.user = User.objects.filter(**params).first()
             if self.user and not self.user.check_password(password):
@@ -136,8 +138,8 @@ class UserFunctionsMixin:
         except User.DoesNotExist:
             pass
         if (
-                settings.PASSWORD_RESET_SHOW_EMAIL_NOT_FOUND
-                or settings.USERNAME_RESET_SHOW_EMAIL_NOT_FOUND
+            settings.PASSWORD_RESET_SHOW_EMAIL_NOT_FOUND
+            or settings.USERNAME_RESET_SHOW_EMAIL_NOT_FOUND
         ):
             self.fail("email_not_found")
 
@@ -330,7 +332,7 @@ class UserDeleteSerializer(CurrentPasswordSerializer):
 class SetUsernameSerializer(UsernameSerializer, CurrentPasswordSerializer):
     class Meta:
         model = User
-        fields = (settings.LOGIN_FIELD, 'current_password')
+        fields = (settings.LOGIN_FIELD, "current_password")
 
 
 class SetUsernameRetypeSerializer(SetUsernameSerializer, UsernameRetypeSerializer):
