@@ -1,16 +1,16 @@
 from django.contrib.auth import login, logout, user_logged_in, user_logged_out
-from django.utils.encoding import force_bytes, force_text
+from django.utils.encoding import force_bytes, force_str
 from django.utils.http import urlsafe_base64_decode, urlsafe_base64_encode
 
 from djoser.conf import settings
 
 
 def encode_uid(pk):
-    return force_text(urlsafe_base64_encode(force_bytes(pk)))
+    return force_str(urlsafe_base64_encode(force_bytes(pk)))
 
 
 def decode_uid(pk):
-    return force_text(urlsafe_base64_decode(pk))
+    return force_str(urlsafe_base64_decode(pk))
 
 
 def login_user(request, user):
