@@ -1,6 +1,5 @@
 from django.contrib.auth import get_user_model, update_session_auth_hash
 from django.contrib.auth.tokens import default_token_generator
-
 from django.utils.timezone import now
 from rest_framework import generics, status, views, viewsets
 from rest_framework.decorators import action
@@ -49,14 +48,14 @@ class UserViewSet(viewsets.ModelViewSet):
     token_generator = default_token_generator
     lookup_field = settings.USER_ID_FIELD
 
-    def permission_denied(self, request, message=None):
+    def permission_denied(self, request, **kwargs):
         if (
             settings.HIDE_USERS
             and request.user.is_authenticated
             and self.action in ["update", "partial_update", "list", "retrieve"]
         ):
             raise NotFound()
-        super().permission_denied(request, message=message)
+        super().permission_denied(request, **kwargs)
 
     def get_queryset(self):
         user = self.request.user
